@@ -102,9 +102,9 @@ class App:
             if debug == "true":
                 application.config["DEBUG"] = True
                 application.config["ENV"] = "development"
-                application.run(host='0.0.0.0', port=8080)
+                application.run(host='0.0.0.0', port=port)
             else:
-                application.run(host='0.0.0.0', port=8080)
+                application.run(host='0.0.0.0', port=port)
 
         except ExecutorException as e:
             raise ExecutorException(status=e.status, reason=e.reason)
